#[non_exhaustive]pub enum MessageOrBool {
Message(Box<Message>),
Bool(bool),
}Expand description
Result type for edit methods that return either a Message or a bool.
Some Telegram API edit methods return the edited Message when called with chat_id
and message_id, but return true when called with inline_message_id.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.