#[non_exhaustive]pub struct Defaults {
pub parse_mode: Option<String>,
pub disable_notification: Option<bool>,
pub protect_content: Option<bool>,
pub allow_sending_without_reply: Option<bool>,
pub link_preview_options: Option<LinkPreviewOptions>,
pub quote: Option<bool>,
}Expand description
Default parameter values merged into every API call when the caller has not provided an explicit value.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parse_mode: Option<String>Default parse mode for text formatting (e.g. "HTML", "MarkdownV2").
disable_notification: Option<bool>Whether to send messages silently by default.
protect_content: Option<bool>Whether to protect forwarded messages from being saved by default.
allow_sending_without_reply: Option<bool>Whether to allow sending without a reply by default.
link_preview_options: Option<LinkPreviewOptions>Default link preview options.
quote: Option<bool>Whether to quote the original message by default when replying.